# WARNING: Please don't edit this file. It was generated by Python/WinRT v2.3.0

import typing
import uuid as _uuid

import winrt.system
from winrt import _winrt_windows_devices_perception_provider

__all__ = [
    "KnownPerceptionFrameKind",
    "PerceptionControlGroup",
    "PerceptionCorrelation",
    "PerceptionCorrelationGroup",
    "PerceptionFaceAuthenticationGroup",
    "PerceptionFrame",
    "PerceptionFrameProviderInfo",
    "PerceptionFrameProviderManagerService",
    "PerceptionPropertyChangeRequest",
    "PerceptionVideoFrameAllocator",
    "IPerceptionFrameProvider",
    "IPerceptionFrameProviderManager",
    "PerceptionStartFaceAuthenticationHandler",
    "PerceptionStopFaceAuthenticationHandler",
]

KnownPerceptionFrameKind = _winrt_windows_devices_perception_provider.KnownPerceptionFrameKind
PerceptionControlGroup = _winrt_windows_devices_perception_provider.PerceptionControlGroup
PerceptionCorrelation = _winrt_windows_devices_perception_provider.PerceptionCorrelation
PerceptionCorrelationGroup = _winrt_windows_devices_perception_provider.PerceptionCorrelationGroup
PerceptionFaceAuthenticationGroup = _winrt_windows_devices_perception_provider.PerceptionFaceAuthenticationGroup
PerceptionFrame = _winrt_windows_devices_perception_provider.PerceptionFrame
PerceptionFrameProviderInfo = _winrt_windows_devices_perception_provider.PerceptionFrameProviderInfo
PerceptionFrameProviderManagerService = _winrt_windows_devices_perception_provider.PerceptionFrameProviderManagerService
PerceptionPropertyChangeRequest = _winrt_windows_devices_perception_provider.PerceptionPropertyChangeRequest
PerceptionVideoFrameAllocator = _winrt_windows_devices_perception_provider.PerceptionVideoFrameAllocator
IPerceptionFrameProvider = _winrt_windows_devices_perception_provider.IPerceptionFrameProvider
IPerceptionFrameProviderManager = _winrt_windows_devices_perception_provider.IPerceptionFrameProviderManager
PerceptionStartFaceAuthenticationHandler = typing.Callable[[typing.Optional[PerceptionFaceAuthenticationGroup]], bool]
PerceptionStopFaceAuthenticationHandler = typing.Callable[[typing.Optional[PerceptionFaceAuthenticationGroup]], None]
